package com.voltage.carl.model;

import java.util.Collections;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.swing.tree.TreeNode;

import com.voltage.carl.dao.DAO;
import com.voltage.carl.dao.DAOFactory;

//@Entity
public enum ProductFamily implements TreeNode, PrettyPrinter {

		SECUREMAIL (1, "SecureMail"),
		SECUREDATA (2, "SecureData Enterprise"),
		PAYMENTS (3, "SecureData Payments"),
		SECUREFILE (4, "SecureFile"),
		CUSTOM (5, "Custom");
		
		private int id;
		
		private String name;
		
		private DAO dao;
		
		private static Map<String, ProductFamily> byName = new HashMap<String, ProductFamily>() ;
		
		static{
			for (ProductFamily pf : ProductFamily.values()) {
				byName.put(pf.name, pf);
			}
		}
		
		public static ProductFamily getFamilybyName(String name) {
			return byName.get(name);
		}
		
		
		private ProductFamily(int id, String name) {
			this.id = id;
			this.name = name;
		}
		
		public int getID(){
			return id;
		}
		
		public String getName() {
			return name;
		}
		
		@Override
		public String toString() {
			return name;
		}
		
		public List<Product> getProducts() {
			if (dao == null) {
				dao = DAOFactory.getDAO();
			}
			return dao.getAllProductsinFamily(this);
		}
		
		///////////
		//
		// TreeNode methods
		//
		//////////
		
		@Override
		public Enumeration<Product> children() {
			return Collections.enumeration(getProducts());
		}

		@Override
		public boolean getAllowsChildren() {
			return true;
		}

		@Override
		public TreeNode getChildAt(int childIndex) {
			return getProducts().get(childIndex);
		}

		@Override
		public int getChildCount() {
			return getProducts().size();
		}

		@Override
		public int getIndex(TreeNode node) {
			return getProducts().indexOf(node);
		}

		@Override
		public TreeNode getParent() {
			return null;
		}

		@Override
		public boolean isLeaf() {
			return getProducts().isEmpty();
		}
	
		public String getType() {
			return "ProductFamily";
		}


		@Override
		public String getDisplayString() {
			return name;
		}

}
